<?php
/*
Plugin Name: Make Text Copyable
Plugin URI: https://eurosaiop.org/make-text-copyable-plugin/
Description: A simple plugin to make text copyable with click using a shortcode.
Version: 1.0
Author: Brad Stephenson
Author URI: https://eurosaiop.org
License: GPL-2.0-or-later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
*/

// Enqueue plugin styles and scripts
function mtc_enqueue_styles() {
    wp_enqueue_style('mtc-style', plugin_dir_url(__FILE__) . 'style.css', array(), '1.0');
    wp_enqueue_script('mtc-script', plugin_dir_url(__FILE__) . 'script.js', array('jquery'), '1.0', true);
}
add_action('wp_enqueue_scripts', 'mtc_enqueue_styles');

// Register plugin settings
function mtc_register_settings() {
    add_option('mtc_text_color', '#000000');
    add_option('mtc_background_color', '#ffffff');
    add_option('mtc_cursor_style', 'pointer');
    register_setting('mtc_settings_group', 'mtc_text_color');
    register_setting('mtc_settings_group', 'mtc_background_color');
    register_setting('mtc_settings_group', 'mtc_cursor_style');
}
add_action('admin_init', 'mtc_register_settings');

// Add plugin settings page
function mtc_add_settings_page() {
    add_options_page('Make Text Copyable', 'Make Text Copyable', 'manage_options', 'mtc-settings', 'mtc_settings_page');
}
add_action('admin_menu', 'mtc_add_settings_page');

// Settings page content
function mtc_settings_page() {
    ?>
    <div class="wrap">
        <h1>Make Text Copyable Settings</h1>
        <form method="post" action="options.php">
            <?php settings_fields('mtc_settings_group'); ?>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Text Color</th>
                    <td><input type="text" name="mtc_text_color" value="<?php echo esc_attr(get_option('mtc_text_color')); ?>" class="my-color-field" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Background Color</th>
                    <td><input type="text" name="mtc_background_color" value="<?php echo  esc_attr(get_option('mtc_background_color')); ?>" class="my-color-field" /></td>
                </tr>
                <tr valign="top">
                    <th scope="row">Cursor Style</th>
                    <td>
                        <select name="mtc_cursor_style">
                            <option value="pointer" <?php selected(get_option('mtc_cursor_style'), 'pointer'); ?>>Pointer</option>
                            <option value="default" <?php selected(get_option('mtc_cursor_style'), 'default'); ?>>Default</option>
                            <option value="crosshair" <?php selected(get_option('mtc_cursor_style'), 'crosshair'); ?>>Crosshair</option>
                            <option value="move" <?php selected(get_option('mtc_cursor_style'), 'move'); ?>>Move</option>
                            <option value="text" <?php selected(get_option('mtc_cursor_style'), 'text'); ?>>Text</option>
                        </select>
                    </td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
        <hr/>
        <div style="margin-top: 20px; padding: 10px; background-color: #e9f7fc; border: 1px solid #cce4ff;">
            <h3>How to Use the Plugin</h3>
            <ul>
                <li>To make text copyable, use the shortcode <code>[MTC-ITEM]Your text here[/MTC-ITEM]</code>.</li>
                <li>You can customize the text color, background color, and cursor style in the plugin settings page.</li>
                <li>Once the shortcode is added, users can click on the text to copy it to their clipboard with an alert saying "Copied".</li>
                <li>The settings you choose here will be applied globally to all text wrapped in the <code>[MTC-ITEM]</code> shortcode.</li>
            </ul>
        </div><hr/>
    </div>
    <?php
}

// Shortcode function - make it case-insensitive and use span
function mtc_shortcode($atts, $content = null) {
    // Retrieve settings
    $text_color = get_option('mtc_text_color', '#000000');
    $background_color = get_option('mtc_background_color', '#ffffff');
    $cursor_style = get_option('mtc_cursor_style', 'pointer');
    
    // Output the span element
    return '<span class="mtc-copyable-text" style="color:' . esc_attr($text_color) . '; background-color:' . esc_attr($background_color) . '; cursor:' . esc_attr($cursor_style) . ';" onclick="copyText(this)">' . do_shortcode($content) . '</span>';
}

// Register shortcode (allow case-insensitive)
function mtc_register_shortcode() {
    add_shortcode('mtc-item', 'mtc_shortcode');
    add_shortcode('MTC-ITEM', 'mtc_shortcode');
    add_shortcode('Mtc-Item', 'mtc_shortcode');
}
add_action('init', 'mtc_register_shortcode');

// Include JavaScript for copying text
function mtc_include_js() {
    ?>
    <script>
        function copyText(element) {
            var text = element.innerText;
            var textarea = document.createElement('textarea');
            textarea.value = text;
            document.body.appendChild(textarea);
            textarea.select();
            document.execCommand('copy');
            document.body.removeChild(textarea);
            alert('Copied');
        }
    </script>
    <?php
}
add_action('wp_footer', 'mtc_include_js'); // Hook to output JS at the footer

// Enqueue styles for color picker
function mtc_enqueue_color_picker($hook_suffix) {
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_script('mtc-color-picker', plugins_url('color-picker.js', __FILE__), array('wp-color-picker'), '1.0', true);
}
add_action('admin_enqueue_scripts', 'mtc_enqueue_color_picker');

// Initialize color picker functionality
function mtc_init_color_picker() {
    ?>
    <script type="text/javascript">
        jQuery(document).ready(function($){
            $('.my-color-field').wpColorPicker();
        });
    </script>
    <?php
}
add_action('admin_footer', 'mtc_init_color_picker');
